@@ -10,7 +10,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'BINDIR': '/python-inst/bin',
  'BINLIBDEST': '/python-inst/lib/python3.5',
  'BLDLIBRARY': '-L. -lpython3.5m',
- 'BLDSHARED': '/usr/bin/ccache /opt/rh/devtoolset-2/root/usr/bin/gcc '
+ 'BLDSHARED': '/usr/bin/ccache gcc '
               '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
               '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
               '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib '
@@ -21,7 +21,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'i686-pc-linux-gnu',
  'BYTESTR_DEPS': '\\',
- 'CC': '/usr/bin/ccache /opt/rh/devtoolset-2/root/usr/bin/gcc '
+ 'CC': '/usr/bin/ccache gcc '
        '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
        '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
        '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib -pthread',
@@ -39,8 +39,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFIGURE_LDFLAGS': '-L/home/buildslave/build/workdir/UnpackedTarball/openssl '
                       '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary',
  'CONFIG_ARGS': "'--prefix=/python-inst' '--with-system-expat' "
-                "'--enable-shared' 'CC=/usr/bin/ccache "
-                '/opt/rh/devtoolset-2/root/usr/bin/gcc '
+                "'--enable-shared' 'CC=/usr/bin/ccache gcc "
                 '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
                 '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
                 "-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib' "
@@ -56,7 +55,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include',
- 'CXX': '/usr/bin/ccache /opt/rh/devtoolset-2/root/usr/bin/g++ -pthread',
+ 'CXX': '/usr/bin/ccache g++ -pthread',
  'DESTDIRS': '/python-inst /python-inst/lib /python-inst/lib/python3.5 '
              '/python-inst/lib/python3.5/lib-dynload',
  'DESTLIB': '/python-inst/lib/python3.5',
@@ -372,7 +371,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_STDARG_PROTOTYPES': 1,
  'HAVE_STDINT_H': 1,
  'HAVE_STDLIB_H': 1,
- 'HAVE_STD_ATOMIC': 0,
+ 'HAVE_STD_ATOMIC': 1,
  'HAVE_STRDUP': 1,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
@@ -480,14 +479,13 @@ build_time_vars = {'ABIFLAGS': 'm',
  'INSTSONAME': 'libpython3.5m.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': '/usr/bin/ccache /opt/rh/devtoolset-2/root/usr/bin/g++ '
-                '-pthread -shared',
+ 'LDCXXSHARED': '/usr/bin/ccache g++ -pthread -shared',
  'LDFLAGS': '-L/home/buildslave/build/workdir/UnpackedTarball/openssl '
             '-L/home/buildslave/build/workdir/LinkTarget/StaticLibrary',
  'LDLAST': '',
  'LDLIBRARY': 'libpython3.5m.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': '/usr/bin/ccache /opt/rh/devtoolset-2/root/usr/bin/gcc '
+ 'LDSHARED': '/usr/bin/ccache gcc '
              '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
              '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
              '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib '
@@ -509,7 +507,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lpthread -ldl  -lutil -lrt',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
- 'LINKCC': '/usr/bin/ccache /opt/rh/devtoolset-2/root/usr/bin/gcc '
+ 'LINKCC': '/usr/bin/ccache gcc '
            '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
            '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
            '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib '
@@ -528,7 +526,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'MACHDEP_OBJS': '',
  'MACHDESTLIB': '/python-inst/lib/python3.5',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': '/usr/bin/ccache /opt/rh/devtoolset-2/root/usr/bin/gcc '
+ 'MAINCC': '/usr/bin/ccache gcc '
            '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
            '-I/home/buildslave/build/workdir/UnpackedTarball/openssl/include '
            '-I/home/buildslave/build/workdir/UnpackedTarball/expat/lib '
